import React from 'react';
import PropTypes from 'prop-types';
import { reduxForm } from 'redux-form';
import { validate as _validate, FormError, Input } from '../../../../components/Forms';
import { Button } from '../../../../components/Buttons';

var schema = {
  type: 'object',
  required: ['username', 'password'],
  properties: {
    username: { type: 'string' },
    password: { type: 'string' }
  },
  additionalProperties: false
};

var LoginForm = function LoginForm(_ref) {
  var anyTouched = _ref.anyTouched,
      error = _ref.error,
      initialError = _ref.initialError,
      pristine = _ref.pristine,
      submitting = _ref.submitting,
      handleSubmit = _ref.handleSubmit;

  var formError = error || !anyTouched && pristine && initialError || null;

  return React.createElement(
    'form',
    { onSubmit: handleSubmit },
    React.createElement(FormError, { error: formError }),
    React.createElement(Input, { name: 'username', label: 'Username or E-mail' }),
    React.createElement(Input, { type: 'password', name: 'password', label: 'Password' }),
    React.createElement(
      Button,
      {
        htmlType: 'submit',
        type: 'primary',
        loading: submitting,
        disabled: submitting
      },
      'Log in'
    )
  );
};

LoginForm.propTypes = {
  anyTouched: PropTypes.bool.isRequired,
  error: PropTypes.string,
  initialError: PropTypes.string,
  pristine: PropTypes.bool.isRequired,
  submitting: PropTypes.bool.isRequired,
  handleSubmit: PropTypes.func.isRequired
};

export default reduxForm({
  form: 'loginForm',
  validate: function validate(values) {
    return _validate(schema, values);
  }
})(LoginForm);