import React from 'react';
import PropTypes from 'prop-types';
import { graphql } from 'react-apollo';
import { Redirect } from 'react-router-dom';
import Helmet from 'react-helmet';
import cookie from 'js-cookie';
import { authenticateByTokenQuery, getUserPermissionsArray } from '../../Auth';
import { Navigation } from '../../../components/Navigation';
import { Notifications } from '../../../components/Notifications';
import { Modals } from '../../../components/Modals';
import { Loading } from '../../../components/Loading';

var Layout = function Layout(_ref) {
  var children = _ref.children,
      data = _ref.data,
      icons = _ref.icons,
      location = _ref.location,
      menuItems = _ref.menuItems,
      title = _ref.title;
  var loading = data.loading,
      error = data.error,
      authenticateByToken = data.authenticateByToken;


  if (loading) {
    return React.createElement(Loading, null);
  }

  if (!loading && error) {
    var errorMessage = error.graphQLErrors.length ? error.graphQLErrors[0].message : error.message;

    return React.createElement(Redirect, { to: { pathname: '/login', state: { from: location, error: errorMessage } } });
  }

  var userPermissions = getUserPermissionsArray(authenticateByToken.user);

  return React.createElement(
    'section',
    { className: 'department-contents' },
    React.createElement(
      Helmet,
      null,
      React.createElement(
        'title',
        null,
        title
      )
    ),
    icons && icons(),
    React.createElement(Navigation, { items: menuItems, userPermissions: userPermissions }),
    React.createElement(
      'main',
      { className: 'department-main' },
      children
    ),
    React.createElement(Notifications, null),
    React.createElement(Modals, null)
  );
};

Layout.propTypes = {
  children: PropTypes.node.isRequired,
  data: PropTypes.object.isRequired,
  icons: PropTypes.func,
  location: PropTypes.object.isRequired,
  menuItems: PropTypes.array.isRequired,
  title: PropTypes.string
};

Layout.defaultProps = {
  title: 'Department'
};

export default graphql(authenticateByTokenQuery, {
  options: function options() {
    return {
      variables: {
        token: cookie.get('token') || ''
      },
      fetchPolicy: 'network-only'
    };
  }
})(Layout);