'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactApollo = require('react-apollo');

var _reactRouterDom = require('react-router-dom');

var _reactHelmet = require('react-helmet');

var _reactHelmet2 = _interopRequireDefault(_reactHelmet);

var _jsCookie = require('js-cookie');

var _jsCookie2 = _interopRequireDefault(_jsCookie);

var _Auth = require('../../Auth');

var _Navigation = require('../../../components/Navigation');

var _Notifications = require('../../../components/Notifications');

var _Modals = require('../../../components/Modals');

var _Loading = require('../../../components/Loading');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Layout = function Layout(_ref) {
  var children = _ref.children,
      data = _ref.data,
      icons = _ref.icons,
      location = _ref.location,
      menuItems = _ref.menuItems,
      title = _ref.title;
  var loading = data.loading,
      error = data.error,
      authenticateByToken = data.authenticateByToken;


  if (loading) {
    return _react2.default.createElement(_Loading.Loading, null);
  }

  if (!loading && error) {
    var errorMessage = error.graphQLErrors.length ? error.graphQLErrors[0].message : error.message;

    return _react2.default.createElement(_reactRouterDom.Redirect, { to: { pathname: '/login', state: { from: location, error: errorMessage } } });
  }

  var userPermissions = (0, _Auth.getUserPermissionsArray)(authenticateByToken.user);

  return _react2.default.createElement(
    'section',
    { className: 'department-contents' },
    _react2.default.createElement(
      _reactHelmet2.default,
      null,
      _react2.default.createElement(
        'title',
        null,
        title
      )
    ),
    icons && icons(),
    _react2.default.createElement(_Navigation.Navigation, { items: menuItems, userPermissions: userPermissions }),
    _react2.default.createElement(
      'main',
      { className: 'department-main' },
      children
    ),
    _react2.default.createElement(_Notifications.Notifications, null),
    _react2.default.createElement(_Modals.Modals, null)
  );
};

Layout.propTypes = {
  children: _propTypes2.default.node.isRequired,
  data: _propTypes2.default.object.isRequired,
  icons: _propTypes2.default.func,
  location: _propTypes2.default.object.isRequired,
  menuItems: _propTypes2.default.array.isRequired,
  title: _propTypes2.default.string
};

Layout.defaultProps = {
  title: 'Department'
};

exports.default = (0, _reactApollo.graphql)(_Auth.authenticateByTokenQuery, {
  options: function options() {
    return {
      variables: {
        token: _jsCookie2.default.get('token') || ''
      },
      fetchPolicy: 'network-only'
    };
  }
})(Layout);